==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ColumnPinningDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnPinningDescription } from "./ColumnPinningDescription";
/**
 * @hidden
 */
export let ColumnPinningDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnPinningDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnPinningDescriptionMetadata.a == null) {
                ColumnPinningDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnPinningDescriptionMetadata.c(ColumnPinningDescriptionMetadata.a);
            }
            if (a.k(ColumnPinningDescriptionMetadata.a)) {
                return;
            }
            a.ab(ColumnPinningDescriptionMetadata.a);
        }
        static c(a) {
            a.item("TargetGridRef", "(w:TargetGrid,wf:TargetGrid)DataRef::object");
            a.item("Title", "String");
            a.item("TitleFontFamily", "(w:TitleFontFamily/FontFamilyTransform,xam:TitleFontFamily,wf:TitleFontFamily,web:titleStyle/FontFamilyTransform)String");
            a.item("TitleFontSize", "(w:TitleFontSize,xam:TitleFontSize,wf:TitleFontSize,web:titleStyle/FontSizeTransform)Number:double");
            a.item("TitleFontStyle", "(w:TitleFontStyle/FontStyleTransform,xam:TitleFontFamily/FontStyleTransform,wf:TitleFontFamily/FontStyleTransform,web:titleStyle/FontStyleTransform)String");
            a.item("TitleFontWeight", "(w:TitleFontWeight/FontWeightTransform,xam:TitleFontFamily/FontWeightTransform,wf:TitleFontFamily/FontWeightTransform,web:titleStyle/FontWeightTransform)String");
            a.item("TitleColor", "Brush");
            a.item("FilterPlaceholderText", "String");
            a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
            a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight;SlingshotLight;SlingshotDark;RevealLight;RevealDark");
            a.item("Density", "ExportedType:string:ControlDisplayDensity");
            a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
            a.item("BackgroundColor", "Brush");
        }
        static d(a) {
            ColumnPinningDescriptionMetadata.b(a);
            a.ad("ColumnPinning", () => new ColumnPinningDescription());
            a.ac("ColumnPinning", ColumnPinningDescriptionMetadata.a);
        }
    }
    ColumnPinningDescriptionMetadata.$t = markType(ColumnPinningDescriptionMetadata, 'ColumnPinningDescriptionMetadata');
    ColumnPinningDescriptionMetadata.a = null;
    return ColumnPinningDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ColumnPinningDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnPinningDescription } from "./ColumnPinningDescription";
/**
 * @hidden
 */
export let ColumnPinningDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnPinningDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnPinningDescriptionMetadata.a == null) {
                ColumnPinningDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnPinningDescriptionMetadata.c(ColumnPinningDescriptionMetadata.a);
            }
            if (a.k(ColumnPinningDescriptionMetadata.a)) {
                return;
            }
            a.ac(ColumnPinningDescriptionMetadata.a);
        }
        static c(a) {
            a.item("TargetGridRef", "(w:TargetGrid,wf:TargetGrid)DataRef::object");
            a.item("Title", "String");
            a.item("TitleFontFamily", "(w:TitleFontFamily/FontFamilyTransform,xam:TitleFontFamily,wf:TitleFontFamily,web:titleStyle/FontFamilyTransform)String");
            a.item("TitleFontSize", "(w:TitleFontSize,xam:TitleFontSize,wf:TitleFontSize,web:titleStyle/FontSizeTransform)Number:double");
            a.item("TitleFontStyle", "(w:TitleFontStyle/FontStyleTransform,xam:TitleFontFamily/FontStyleTransform,wf:TitleFontFamily/FontStyleTransform,web:titleStyle/FontStyleTransform)String");
            a.item("TitleFontWeight", "(w:TitleFontWeight/FontWeightTransform,xam:TitleFontFamily/FontWeightTransform,wf:TitleFontFamily/FontWeightTransform,web:titleStyle/FontWeightTransform)String");
            a.item("TitleColor", "Brush");
            a.item("FilterPlaceholderText", "String");
            a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
            a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight;SlingshotLight;SlingshotDark;RevealLight;RevealDark");
            a.item("Density", "ExportedType:string:ControlDisplayDensity");
            a.item("Density@names", "Auto;Comfortable;Cosy;Compact;Minimal");
            a.item("BackgroundColor", "Brush");
        }
        static d(a) {
            ColumnPinningDescriptionMetadata.b(a);
            a.ae("ColumnPinning", () => new ColumnPinningDescription());
            a.ad("ColumnPinning", ColumnPinningDescriptionMetadata.a);
        }
    }
    ColumnPinningDescriptionMetadata.$t = markType(ColumnPinningDescriptionMetadata, 'ColumnPinningDescriptionMetadata');
    ColumnPinningDescriptionMetadata.a = null;
    return ColumnPinningDescriptionMetadata;
})();
